@@ -31,6 +31,7 @@
 #include <kio/job.h>
 #include <kio/deletejob.h>
 #include <kio/paste.h>
+#include <kioglobal_p.h>
 #include <kprotocolinfo.h>
 #include <kurlmimedata.h>
 
@@ -39,9 +40,14 @@
 #include <kconfiggroup.h>
 
 #include <errno.h>
-#include <utime.h>
 #include <time.h>
+#ifdef Q_OS_WIN
+#include <sys/utime.h>
+#else
+#include <utime.h>
 #include <sys/time.h>
+#endif
+
 
 #include <QClipboard>
 #include <QApplication>
@@ -114,7 +120,7 @@ static void createTestSymlink(const QString &path)
     // Create symlink if it doesn't exist yet
     QT_STATBUF buf;
     if (QT_LSTAT(QFile::encodeName(path).constData(), &buf) != 0) {
-        bool ok = symlink("/IDontExist", QFile::encodeName(path).constData()) == 0; // broken symlink
+        bool ok = KIOPrivate::createSymlink(QStringLiteral("/IDontExist"), path); // broken symlink
         if (!ok) {
             qFatal("couldn't create symlink: %s", strerror(errno));
         }
