@@ -20,7 +20,7 @@
 #ifndef KFILEITEM_H
 #define KFILEITEM_H
 
-#include <kio/kiocore_export.h>
+#include "kiocore_export.h"
 #include <kio/global.h>
 #include <kacl.h>
 #include <kio/udsentry.h>
@@ -63,9 +63,6 @@ public:
 
     /**
      * Null KFileItem. Doesn't represent any file, only exists for convenience.
-     *
-     * NOTE KDE 4.0 when porting from KFileItem* to KFileItem&:
-     * '(KFileItem*)a==0'  becomes '(KFileItem)a.isNull()'
      */
     KFileItem();
 
@@ -364,7 +361,7 @@ public:
      * This will not try to determine the mimetype if unknown.
      * @return the known mime type
      */
-    QMimeType currentMimeType() const; // KDE4: was mimeTypePtr()
+    QMimeType currentMimeType() const;
 
     /**
      * @return true if we have determined the final icon of this file already.
@@ -438,22 +435,6 @@ public:
      */
     KIO::UDSEntry entry() const;
 
-    /**
-     * Used when updating a directory. marked == seen when refreshing.
-     * @return true if the file item is marked
-     */
-    bool isMarked() const;
-    /**
-     * Marks the item.
-     * @see isMarked()
-     */
-    void mark();
-    /**
-     * Unmarks the item.
-     * @see isMarked()
-     */
-    void unmark();
-
     /**
      * Return true if this item is a regular file,
      * false otherwise (directory, link, character/block device, fifo, socket)
